function auxval = auxfunc(eulco, y, q1, q2, q3, W, iaux)
% auxval = auxfunc(eulco, q1, q2, q, W)
% This function computes the value of the auxiliary function 
% coresponding to integral of conjg(q)*dq/dx.
%
%   eulco: contains the dsicretization coefficients
%   y: values of normal coordinates
%   q1, q2 and q3: the eigenfunctions at stations i-2, i-1 and i-th 
%                 (the currenet) streamwise station
%   W: contains spectral inetgral weights for Chebuychev polynomials
%   iaux: =1 integral norm, =2 max(u)
%
% (c) Ardeshir Hanifi & David Tempelmann, 2014
%


N=length(y);

% Compute umax
umax1 = findqmax(y,q1(1:N));
umax2 = findqmax(y,q2(1:N));
umax3 = findqmax(y,q3(1:N));

% Compute the auxiliary condition
if (iaux==1)
    % Compute derivative of q
    dqdx = eulco(1)*q1 + eulco(2)*q2 + eulco(3)*q3;
    auxval = q3'*blkdiag(W,W,W,W)*dqdx;
else
    auxval = (eulco(1)*umax1 + eulco(2)*umax2 + eulco(3)*umax3);
end

end
