function [ fx ] = dfx( f,x,difforder )
% [ fx ] = dfx( f,x,difforder )
% DFX Computes derivatives of F with respect to x
% 
% Input
%   f: funxtion values
%   x: values of the variable
%   difforder: =1 first-order Euler, =2 second-order Euler scheme
%
% Output
%   fx: df/dx
%
% (c) Ardeshir Hanifi & David Tempelmann, 2014
%

idim=length(f);
fx=zeros(size(f));
fx(1)=(f(1)-f(2))/(x(1)-x(2));
for i=2:idim
    if (min(difforder,i-1)==1)             % first order Euler
        dx1=x(i)-x(i-1);
        fx(i)=(f(i)-f(i-1))/dx1;
    else                          % second order Euler
        dx1=x(i)-x(i-1);
        dx2=x(i-1)-x(i-2);
        c2=dx1/(dx2*(dx2+dx1));
        c1=-(dx2+dx1)/(dx1*dx2);
        c0=(2.*dx1+dx2)/(dx1*(dx2+dx1));
        fx(i)=c2*f(i-2)+c1*f(i-1)+c0*f(i);
    end
end

