function [qmax] = findqmax(y,q)
% [qmax] = findqmax(q,y)
% This function finds the value of q with the maximum absolute value 
% by ploynomial fitting.
%
% Input:
%    y: array containing coordinates of grid points
%    q: function values at gridpoints given in y
%
% Output:
%    qmax: estimated value of q with maximum absolute value
%
% (c) Ardeshir Hanifi & David Tempelmann, 2014
%

N=length(y);

% Find the maximum of abs(q) on the original grid
qabs=abs(q);
[qmax, imax]=max(qabs);

if (imax==1 || imax==N)
    disp('Findqmax: max values at boundaries')
    qmax=q(imax);
    return;
end

% Fit polynomial to data
Np=2; % order of polynomial
i1=max(1,imax-floor(Np/2));
i2=min(i1+Np,N);
p = polyfit(y(i1:i2),qabs(i1:i2),Np);

% find zero of derivative of the polynomial
dp = polyder(p);
y0=[y(i1) y(i2)];
fun=@(x)polyval(dp,x);
ymax=fzero(fun,y0);

% Find the maximum on the interpolated grid
p = polyfit(y(i1:i2),q(i1:i2),Np);
qmax=polyval(p,ymax);

end
