function [ sigma ] = growth( x,alpha,q,W )
% [ sigma ] = growth( x,alpha,q,W )
% GROWTH computes the nonlocal growthrate of perturbations
%
% Input
%   x: streamwise coordinate of stations
%   alpha: vector containig streamwise wavenumber at all x-stations
%   q:  matrix containing eigenfunctions at all x-stations
%   W: is the weightfunction of spectral integration
%
% Output 
%    sigma: the nonlocal growth rate.
%
%
% (c) Ardeshir Hanifi & David Tempelmann, 2014
%

N=length(q(:,1))/4;

% Growthrate based on disturbance energy
energy=zeros(size(alpha));
umax=zeros(size(alpha));
for k=1:length(x)
    energy(k)=abs(0.5*q(1:3*N,k)'*blkdiag(W,W,W)*q(1:3*N,k));            
end
sigma=-imag(alpha)+dfx( log(sqrt(energy)),x,1 );
sigma(1)=-imag(alpha(1)); % Local growth rate

end

