function [q,alpha] = localOSS(alphainit, U, D1, D2, beta, omega, Re)
% [q,alpha] = localOSS(alphainit, U, D1, D2, beta, omega, Re) computes eigenvalue of 
% local spatial stability equation
%
% Input:
%    alphainit: start approximation of eigenvalue
%    U: structure containing mean flow velocity field and its derivatives
%    D1 and D2: matrices corresponding to operator of first- and second derivative
%    beta: spanwise wavenumber of perurbation
%    omega: angular frequency of perturbation
%    Re: Reynolds number
%
% Outout:
%   q: eigenfunction
%   alpha: eigenvalue (streamwise wavenumber)
%
% (c) Ardeshir Hanifi & David Tempelmann, 2014
%

% Find eigenvalue of spatial OSS system using a secant method
loop = true;
iloop = 0;
alpha = alphainit;
local=true;
N=length(U.u);

alpha1=0;
v01=0;

disp([' ']);
disp(['**** Local analysis for Re= ',num2str(Re),', F=',num2str(omega/Re)]);
disp([' ']);
while loop
    iloop = iloop +1;
    
    [RHS,LHS] = operator(local, U, alpha, D1, D2, beta, omega, Re);
    q = LHS\RHS;
    v02 = q(2*N);
    [ alpha, alpha1, v01 ] = extrapol( alpha1, alpha, v01, v02, iloop);
    
    disp(['It: ', num2str(iloop), ' ,alpha: ', num2str(alpha), ' , w0: ', num2str(abs(v02))]);
    
    if abs(v02) <= 2e-8
        loop = false;
    end
    
    if (iloop>50) error ('**** No converged solution found'); end

end
