%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                         %
% Helmholtz2D:		Solve the 2D Helmholtz EVP                            %
%                                                                         %
%                       (c) 2014 vt_productions                           %
%                                                                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear;

% Set number of discretization nodes in the x and y spatial directions
Nx=48;
Ny=48;

% Set grids and collocation derivative matrices in the resolved spatial
% directions

Lx = 1;
Ly = 1;
[xgl,d1y,d2y] = set_chebyshev_derivative_matrices(Ny);
[xgrid,d1x,d2x] = map_y( 0., Lx, xgl, d1y, d2y);
[ygrid,d1y,d2y] = map_y( 0., Ly, xgl, d1y, d2y);

% Form the EVP and impose boundary conditions
[ A ] = form_Helmholtz_2D( Nx, Ny, d2x, d2y);
[ A ] = impose_Helmholtz_BCs( Nx, Ny, A );

% Solve the EVP using the QZ algorithm (full spectrum computation)
[V,lambda]=eig(A);

% Extract the eigenvalues
omegar=real(diag(lambda));
omegai=imag(diag(lambda));

% Plot the results
[phi] = plot_Helmholtz2D(-diag(lambda)/pi^2,V,ygrid,xgrid,Lx,Ly);

% END