function [ A ] = impose_Helmholtz_BCs( Nx, Ny, A )

% impose_Helmholtz_BCs: Impose homogeneous Dirichlet BCs 
%
% INPUTS
% Nx, Ny:     number of Chebyshev collocation nodes
%
% INPUT/OUTPUT
% A:          LHS of the discretized Helmholtz operator in 2D
%
% (c) 2014 vt_productions


% .. phi=0 at y = Ly..

for i=1:Nx+1
      A(i*(Ny+1),:)=0;
      A(i*(Ny+1),i*(Ny+1))=1.;
end

% .. phi=0 at y = 0..

for i=1:Nx+1
      A(i+(i-1)*Ny,:)=0;
      A(i+(i-1)*Ny,i+(i-1)*Ny)=1.;
end

% .. phi=0 at x = Lx..

for i=2:Ny
      A(i,:)=0;
      A(i,i)=1.;
end

% .. phi=0 at x = 0..

for i=2:Ny
      A(Nx*(Ny+1)+i,:)=0;
      A(Nx*(Ny+1)+i,Nx*(Ny+1)+i)=1.;
end


return