%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                         %
% EVP2D:      Set up and solve the 2d BiGlobal EVP                        %
%                                                                         %
%                       (c) 2014 vt_productions                           %
%                                                                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear;

% Set number of discretization nodes in the x and y spatial directions
Nx=4;
Ny=128;

% Set flow parameters
Re = 10000;
alpha = 1;
% JHT test case:  OMEGAR=0.23752649, OMEGAI=0.00373967

% Re=7500;
% alpha=1;
% CHQZ test case: OMEGAR=0.24989154, OMEGAI=0.00223497

Lx=2*pi/alpha;

% Set grids and collocation derivative matrices in the resolved spatial
% directions
[xgrid]=set_x_grid(Nx);
[d1x,d2x]=set_fourier_derivative_matrices(Nx);
[xgrid,d1x,d2x] = map_x( 0., Lx, xgrid, d1x, d2x);
[xgl,d1y,d2y] = set_chebyshev_derivative_matrices(Ny);

% Form the EVP and impose boundary conditions
[ A, B ] = form_EVP2d( Nx, Ny, Re, xgl, d1x, d2x, d1y, d2y);
[ A, B ] = impose_BCs_EVP2d( Nx, Ny, d1y, A, B );

% Solve the EVP using the QZ algorithm (full spectrum computation)
[V,lambda]=eig(A,B,'qz');

% Extract the eigenvalues
omegar=real(diag(lambda));
omegai=imag(diag(lambda));

% Plot the results
plot_EVP2d(1i*diag(lambda),V,xgl,xgrid,Re,alpha)

% END