function [ der1x, der2x ] = calculate_ddx( Nx, d1x, d2x, x );
%
%CALCULATE_DDX: Use Fourier spectral collocation to compute 
%               1st and 2nd derivatives of a periodic function
% INPUTS
% Nx:   number of (mapped) Fourier collocation nodes 
%       discretizing the periodic domain (not passed as an argument)
% x:    periodic function defined on the (mapped) domain
% d1x:  1st Fourier collocation derivative matrix, 
%       modified by the mapping transformation
% d2x:  2nd Fourier collocation derivative matrix, 
%       modified by the mapping transformation
% OUTPUTS
% der1x:1st derivative of the periodic function x
% der2x:2nd derivative of the periodic function x
%
% (c) 2014 vt_productions

for j =1:Nx
    der1x(j)=dot(d1x(j,:),x);
    der2x(j)=dot(d2x(j,:),x);
end
        
return