function []=plot_EVP2d(eigval,eigvec,y,x,Re,alpha)
% plot_EVP2d plots the eigenfunctions computed by EVP2d
%
Ny=length(y);
Nx=length(x);
NN=Nx*Ny;
[X,Y]=meshgrid(x,y); 
lambda=2*pi/alpha;
x1=linspace(0,x(end)+lambda,2*Nx*5);

disp('extend of x-domain'),x(end)
disp('# of points'),2*Nx*5

[X1,Y1]=meshgrid(x1,y); 

disp('Right click to pick the mode. Left click to stop');
button=1;
while button==1
    
    figure(1)
    plot(real(eigval),imag(eigval),'o',[-100 100],[0 0],'r-');
    axis([0,1,-1,0.1]);axis('square');
    title(strcat({'Re= '},{num2str(Re)},{' , alpha= '},{num2str(alpha)}));
    ylabel('imag(\omega)')
    xlabel('real(\omega)')
    
    % pick the eigenfunction
    [xp,yp,button] = ginput(1);
    a=xp+sqrt(-1)*yp;
    [c,locate]=min(abs(eigval-a));
    
    % extract different components of eigenfunction
    u=reshape(eigvec(1:NN,locate),Ny,Nx);
    v=reshape(eigvec(NN+1:2*NN,locate),Ny,Nx);
    p=reshape(eigvec(2*NN+1:3*NN,locate),Ny,Nx);
    
    % interpolate on a finer grid
    u=interp2([X X+lambda],[Y Y],[u u],X1,Y1,'spline');
    v=interp2([X X+lambda],[Y Y],[v v],X1,Y1,'spline');
    p=interp2([X X+lambda],[Y Y],[p p],X1,Y1,'spline');
    
    % scale with respective maxima
    u = u/max(max(abs(u)));
    v = v/max(max(abs(v)));
    p = p/max(max(abs(p)));
    
    %define contours to plot
    vecp = [+0.1 +0.2 +0.3 +0.4 +0.5 +0.6 +0.7 +0.8 +0.9 +1];
    vecm = [-0.1 -0.2 -0.3 -0.4 -0.5 -0.6 -0.7 -0.8 -0.9 -1];
    
    % u
    figure(2)
    [C,h] = contour(X1/lambda,Y1,real(u),vecp,'k-');
    hold on;
    [C,h] = contour(X1/lambda,Y1,real(u),vecm,'k:');
    [C,h] = contour(X1/lambda,Y1,real(u),[0 0],'k.');
    hold off;
    axis('square');
    
%    [C,h] = contourf(X1/lambda,Y1,real(u),10);
%    set(h,'LineStyle','none')
%    colormap('jet'); title('u'); ylabel('y'); xlabel('x/\lambda');
%     
    % v
    figure(3)
    [C,h] = contour(X1/lambda,Y1,real(v),vecp,'k-');
    hold on;
    [C,h] = contour(X1/lambda,Y1,real(v),vecm,'k:');
    [C,h] = contour(X1/lambda,Y1,real(v),[0 0],'k.');
    hold off;
    axis('square');
    
%    [C,h] = contourf(X1/lambda,Y1,real(v),10);
%    set(h,'LineStyle','none')
%    colormap('jet'); title('v'); ylabel('y'); xlabel('x/\lambda');
    
    % Pressure
    figure(4)
    [C,h] = contour(X1/lambda,Y1,real(p),vecp,'k-');
    hold on;
    [C,h] = contour(X1/lambda,Y1,real(p),vecm,'k:');
    [C,h] = contour(X1/lambda,Y1,real(p),[0 0],'k.');
    hold off;
    axis('square');

%    [C,h] = contourf(X1/lambda,Y1,real(p),10);
%    set(h,'LineStyle','none')
%    colormap('jet'); title('p'); ylabel('y'); xlabel('x/\lambda');

end
end



